@@ -57,7 +57,7 @@ struct _Listener {
 typedef struct _LTable LTable;
 
 struct _LTable {
-  GNode* tree; /* Represents the config "filesystem" namespace. 
+  GNode* tree; /* Represents the configuration "filesystem" namespace. 
                 *  Kept sorted. 
                 */
   GPtrArray* listeners; /* Listeners are also kept in a flat array here, indexed by connection number */
@@ -366,9 +366,10 @@ ltable_insert(LTable* lt, const gchar* where, Listener* l)
 
       while (across != NULL)
         {
-          lte = across->data;
           int cmp;
 
+          lte = across->data;
+
           cmp = strcmp(lte->name, dirnames[i]);
 
           if (cmp == 0)
